@@ -36,7 +36,7 @@ if (!defined('SM_PATH'))
 function login_redirect_version() 
 {
 
-    return '1.0';
+    return '1.1-1.2.0';
 
 }
 
